@@ -43,11 +43,6 @@ ObjectNodeDialog::ObjectNodeDialog(UMLView * pView, ObjectNodeWidget * pWidget)
     m_bChangesMade(false)
 {
     setCaption(i18n("Properties"));
-    setButtons(Ok | Apply | Cancel | Help);
-    setDefaultButton(Ok);
-    setModal(true);
-    setFaceType(KPageDialog::List);
-    showButtonSeparator(true);
     setupPages();
     connect(this, SIGNAL(okClicked()), this, SLOT(slotOk()));
     connect(this, SIGNAL(applyClicked()), this, SLOT(slotApply()));
@@ -77,9 +72,7 @@ void ObjectNodeDialog::slotShowState()
     m_GenPageWidgets.stateL->show();
     m_GenPageWidgets.stateLE->show();
 
-    if (m_pObjectNodeWidget->state() != NULL) {
-        m_GenPageWidgets.stateLE->setText(m_pObjectNodeWidget->state());
-    }
+    m_GenPageWidgets.stateLE->setText(m_pObjectNodeWidget->state());
 }
 
 void ObjectNodeDialog::slotHideState()
@@ -158,16 +151,16 @@ void ObjectNodeDialog::setupGeneralPage()
     else {
         uWarning() << "type of ObjectNodeWidget is out of range! Value = " << type;
     }
-    Dialog_Utils::makeLabeledEditField(m_GenPageWidgets.generalGB, generalLayout, 0,
+    Dialog_Utils::makeLabeledEditField(generalLayout, 0,
                                     m_GenPageWidgets.typeL, i18n("Object Node type:"),
                                     m_GenPageWidgets.typeLE, objType);
     m_GenPageWidgets.typeLE->setEnabled(false);
 
-    Dialog_Utils::makeLabeledEditField(m_GenPageWidgets.generalGB, generalLayout, 1,
+    Dialog_Utils::makeLabeledEditField(generalLayout, 1,
                                     m_GenPageWidgets.nameL, i18n("Object Node name:"),
                                     m_GenPageWidgets.nameLE);
 
-    Dialog_Utils::makeLabeledEditField(m_GenPageWidgets.generalGB, generalLayout, 2,
+    Dialog_Utils::makeLabeledEditField(generalLayout, 2,
                                     m_GenPageWidgets.stateL, i18nc("enter state label", "State :"),
                                     m_GenPageWidgets.stateLE);
     m_GenPageWidgets.stateL->hide();
@@ -209,7 +202,7 @@ void ObjectNodeDialog::setupGeneralPage()
 
     if (type != ObjectNodeWidget::Buffer && type != ObjectNodeWidget::Data && type != ObjectNodeWidget::Flow) {
         m_GenPageWidgets.nameLE->setEnabled(false);
-        m_GenPageWidgets.nameLE->setText("");
+        m_GenPageWidgets.nameLE->setText(QString());
     } else
         m_GenPageWidgets.nameLE->setText(m_pObjectNodeWidget->name());
 }
@@ -222,9 +215,7 @@ void ObjectNodeDialog::showState()
     m_GenPageWidgets.stateL->show();
     m_GenPageWidgets.stateLE->show();
 
-    if (m_pObjectNodeWidget->state() != NULL) {
-        m_GenPageWidgets.stateLE->setText(m_pObjectNodeWidget->state());
-    }
+    m_GenPageWidgets.stateLE->setText(m_pObjectNodeWidget->state());
 }
 
 #include "objectnodedialog.moc"
